version 13.1

set more off

capture log close

log using sociallegitimacy.log, replace

*     ***************************************************************** *;
*     ***************************************************************** *;
*   File-Name:  sociallegitimacy.do                                     *;
*   Date:       August 5, 2014	                                        *;
*   Author:     Dellmuth and Tallberg                                   *;
*   Purpose:    Replicate results for paper "The social legitimacy of   *;
*				international organizations"						    *;
*   Input File: ris.dta                                                 *;
*   Output File:sociallegitimacy.log                                    *;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*     Code variable sample to replicate results for sample used in paper*;
*     ****************************************************************  *;

quietly reg unconf scalt lcso demindex unprob netc govconf identity inc edu /// 
age cognitive gender trust ucdp_loc ti_cpi colonial

gen sample=0

replace sample=1 if e(sample)

*     ****************************************************************  *;
*     Get summary statistsics for variable U.N. confidence 		        *;
*     ****************************************************************  *;

sum unconfp if sample==1

*     ****************************************************************  *;
*     Replicate tables in Appendix A							        *;
*     ****************************************************************  *;

*Table A1
by cname, sort: tabstat scalt cso netc ucdp_loc ti_cpi colonial if ///
sample==1, stats(mean n) 

*Table A2
tabstat unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc ti_cpi colonial if sample==1 ///
, stats(min mean max sd) columns(statistics) 

*Table A3
corr scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc ti_cpi colonial if sample==1 


*     ****************************************************************  *;
*     Replicate figure 1										        *;
*     ****************************************************************  *;

#delimit ;
graph hbar (mean) unconfp if sample==1, 
over(cname, label(labcolor(black) labsize(small)) sort(unconfp)) 
ytitle(Percentage of respondents having quite a lot and a great deal of confidence in the U.N.) 
ytitle(, size(small)) ylabel(, labsize(small)) ymtick(, labsize(small)) scheme(sj)
graphregion(color(white))
;
#delimit cr


*     ****************************************************************  *;
*     Replicate table 1											        *;
*     ****************************************************************  *;

gllamm unconf if sample==1, l(ologit) i(countryyear) robust

eststo empty

esttab empty, starlevels(* .05 ** .01) main(b %9.3f) ///
se(%9.3f)  bic scalars(ll N) nodepvars  replace 


*     ****************************************************************  *;
*     Replicate table 2											        *;
*     ****************************************************************  *;

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust if sample==1, l(ologit) i(countryyear) robust

eststo model1

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo model2

esttab model1 model2, starlevels(* .05 ** .01) main(b %9.3f) ///
se(%9.3f) bic scalars(ll N) nodepvars replace 

*     ****************************************************************  *;
*     Get odds ratios for model 2								        *;
*     ****************************************************************  *;

estimates restore model2

gllamm, eform

*     ****************************************************************  *;
*     Replicate robustness checks 								        *;
*     ****************************************************************  *;

*For variable net contributions

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ti_cpi if sample==1, ///
l(ologit) i(countryyear) robust

eststo check1

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check2

esttab check1 check2, starlevels(* .05 ** .01) main(b %9.3f) ///
se(%9.3f) bic scalars(ll N) nodepvars replace 


*For variable civil society representation

gllamm unconf scalt lcsocap demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust if sample==1, ///
l(ologit) i(countryyear) robust

eststo check3

gllamm unconf scalt lcsocap demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check4

gllamm unconf scalt cso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check5

gllamm unconf scalt cso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check6

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust if sample==1&cname~="India"& ///
cname~="United States", l(ologit) i(countryyear) robust

eststo check7

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc ti_cpi colonial if sample==1&cname~="India"& ///
cname~="United States", l(ologit) i(countryyear) robust

eststo check8

esttab check3 check4 check5	check6 check7 check8, starlevels(* .05 ** .01) ///
main(b %9.3f) se(%9.3f) bic scalars(ll N) nodepvars replace 


*Interaction models with variable cognitive mobilization

gllamm unconf scalt cognitive scaltxcognitive lcso demindex unprob lnetc ///
govconf identity inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check9

gllamm unconf lcso cognitive lcsoxcognitive scalt demindex unprob lnetc govconf ///
identity inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check10

gllamm unconf demindex cognitive demindexxcognitive scalt lcso unprob lnetc ///
govconf identity inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check11

gllamm unconf unprob cognitive unprobxcognitive scalt lcso demindex lnetc ///
govconf identity inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check12

gllamm unconf lnetc cognitive lnetcxcognitive scalt lcso demindex unprob govconf ///
identity inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check13

gllamm unconf govconf cognitive govconfxcognitive scalt lcso demindex unprob ///
lnetc identity inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check14

esttab check9 check10 check11 check12 check13 check14, starlevels(* .05 ** .01) ///
main(b %9.3f) se(%9.3f) bic scalars(ll N) nodepvars replace 


*Interaction models with variable identity

set more off

gllamm unconf scalt identity  scaltxidentity lcso demindex unprob lnetc ///
govconf cognitive inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check15

gllamm unconf lcso identity lcsoxidentity scalt demindex unprob lnetc govconf ///
cognitive inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check16

gllamm unconf demindex identity demindexxidentity scalt lcso unprob lnetc ///
govconf cognitive inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check17

gllamm unconf unprob identity unprobxidentity scalt lcso demindex lnetc ///
govconf cognitive inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check18

gllamm unconf lnetc identity lnetcxidentity scalt lcso demindex unprob govconf ///
cognitive inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check19

gllamm unconf govconf identity govconfxidentity scalt lcso demindex unprob ///
lnetc cognitive inc edu age gender trust ucdp_loc ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check20

esttab check15 check16 check17 check18 check19 check20, starlevels(* .05 ** .01) ///
main(b %9.3f) se(%9.3f) bic scalars(ll N) nodepvars replace 


*Heckman selection models

tab unconf, nol
recode unconf (3=1) (2=1) (.b=0) (.e=0) , gen(confunrd)
tab confunrd

heckman unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ///
, select(confunrd = edu inc cognitive) twostep
eststo check21

heckman unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc ti_cpi colonial ///
, select(confunrd = edu inc cognitive) twostep
eststo check22

esttab check21 check22, starlevels(* .05 ** .01)


*For country-level variables

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ucdp_loc if sample==1, ///
l(ologit) i(countryyear) robust

eststo check23

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ti_cpi if sample==1, ///
l(ologit) i(countryyear) robust

eststo check24

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check25

gllamm unconf scalt lcso demindex unprob lnetc govconf identity inc edu ///
age cognitive gender trust ti_cpi colonial if sample==1, ///
l(ologit) i(countryyear) robust

eststo check26

esttab check23 check24 check25 check26, starlevels(* .05 ** .01) main(b %9.3f) ///
se(%9.3f) bic scalars(ll N) nodepvars replace 

log close

exit
